==> openjdk-src-11.0.1.u13-2-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ms.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ms extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_ERN = "ERN";
        final Object[][] data = new Object[][] {
            { "mwk", "Kwacha Malawi" },
            { "FJD", "FJD" },
            { "MXN", "MXN" },
            { "STD", "STD" },
            { "LVL", "LVL" },
            { "SCR", "SCR" },
            { "CDF", "CDF" },
            { "BBD", "BBD" },
            { "mga", "Ariary Malagasy" },
            { "HNL", "HNL" },
            { "UGX", "UGX" },
            { "ZAR", "ZAR" },
            { "bam", "Mark Boleh Tukar Bosnia-Herzegovina" },
            { "egp", "Paun Mesir" },
            { "CUC", "CUC" },
            { "ssp", "Paun Sudan selatan" },
            { "BSD", "BSD" },
            { "nio", "Cordoba Nicaragua" },
            { "SDG", "SDG" },
            { "nzd", "Dolar New Zealand" },
            { "IQD", "IQD" },
            { "brl", "Real Brazil" },
            { "CUP", "CUP" },
            { "GMD", "GMD" },
            { "fjd", "Dolar Fiji" },
            { "RSD", "RSD" },
            { "mxn", "Peso Mexico" },
            { "std", "Dobra Sao Tome dan Principe (1977\u20132017)" },
            { "lvl", "Lats Latvia" },
            { "scr", "Rupee Seychelles" },
            { "cdf", "Franc Congo" },
            { "bbd", "Dolar Barbados" },
            { "MYR", "RM" },
            { "hnl", "Lempira Honduras" },
            { "ugx", "Syiling Uganda" },
            { "FKP", "FKP" },
            { "zar", "Rand Afrika Selatan" },
            { "stn", "Dobra Sao Tome dan Principe" },
            { "UYU", "UYU" },
            { "cuc", "Peso Boleh Tukar Cuba" },
            { "bsd", "Dolar Bahamas" },
            { "CVE", "CVE" },
            { "OMR", "OMR" },
            { "sdg", "Paun Sudan" },
            { "KES", "KES" },
            { "SEK", "SEK" },
            { "BTN", "BTN" },
            { "iqd", "Dinar Iraq" },
            { "GNF", "GNF" },
            { "cup", "Peso Cuba" },
            { "gmd", "Dalasi Gambia" },
            { "MZN", "MZN" },
            { "twd", "Dolar Taiwan Baru" },
            { "ARS", "ARS" },
            { "rsd", "Dinar Serbia" },
            { "QAR", "QAR" },
            { "myr", "Ringgit Malaysia" },
            { "IRR", "IRR" },
            { "fkp", "Paun Kepulauan Falkland" },
            { "xof", "Franc CFA BCEAO" },
            { "THB", "THB" },
            { "UZS", "UZS" },
            { "uyu", "Peso Uruguay" },
            { "BDT", "BDT" },
            { "cve", "Escudo Tanjung Verde" },
            { "omr", "Rial Oman" },
            { "LYD", "LYD" },
            { "kes", "Syiling Kenya" },
            { "sek", "Krona Sweden" },
            { "KWD", "KWD" },
            { "btn", "Ngultrum Bhutan" },
            { "RUB", "RUB" },
            { "gnf", "Franc Guinea" },
            { "ISK", "ISK" },
            { "mzn", "Metikal Mozambique" },
            { "ars", "Peso Argentina" },
            { "qar", "Rial Qatar" },
            { "MKD", "MKD" },
            { "irr", "Rial Iran" },
            { "DZD", "DZD" },
            { "thb", "Baht Thai" },
            { "uzs", "Som Uzbekistan" },
            { "xpf", "Franc CFP" },
            { "PAB", "PAB" },
            { "SGD", "SGD" },
            { "bdt", "Taka Bangladesh" },
            { "KGS", "KGS" },
            { "lyd", "Dinar Libya" },
            { "kwd", "Dinar Kuwait" },
            { "rub", "Rubel Rusia" },
            { "CHF", "CHF" },
            { "HRK", "HRK" },
            { "isk", "Krona Iceland" },
            { "DJF", "DJF" },
            { "mkd", "Denar Macedonia" },
            { "TZS", "TZS" },
            { "dzd", "Dinar Algeria" },
            { "pab", "Balboa Panama" },
            { "sgd", "Dolar Singapura" },
            { "KHR", "KHR" },
            { "IDR", "IDR" },
            { "kgs", "Som Kyrgystani" },
            { "KYD", "KYD" },
            { "BWP", "BWP" },
            { "SHP", "SHP" },
            { "TJS", "TJS" },
            { "xaf", "Franc CFA BEAC" },
            { "AED", "AED" },
            { "RWF", "RWF" },
            { "chf", "Franc Switzerland" },
            { "hrk", "Kuna Croatia" },
            { "djf", "Franc Djibouti" },
            { "DKK", "DKK" },
            { "BGN", "BGN" },
            { "MMK", "MMK" },
            { "NOK", "NOK" },
            { "SYP", "SYP" },
            { "tzs", "Syiling Tanzania" },
            { "vnd", "Dong Vietnam" },
            { "aud", "Dolar Australia" },
            { "LKR", "LKR" },
            { "khr", "Riel Kemboja" },
            { "CZK", "CZK" },
            { "idr", "Rupiah Indonesia" },
            { "kyd", "Dolar Kepulauan Cayman" },
            { "HTG", "HTG" },
            { "bwp", "Pula Botswana" },
            { "shp", "Paun Saint Helena" },
            { "tjs", "Somoni Tajikistan" },
            { "BHD", "BHD" },
            { "rwf", "Franc Rwanda" },
            { "aed", "Dirham Emiriah Arab Bersatu" },
            { "KZT", "KZT" },
            { "SZL", "SZL" },
            { "dkk", "Krone Denmark" },
            { "YER", "YER" },
            { "bgn", "Lev Bulgaria" },
            { "AFN", "AFN" },
            { "mmk", "Kyat Myanma" },
            { "nok", "Krone Norway" },
            { "syp", "Paun Syria" },
            { "AWG", "AWG" },
            { "NPR", "NPR" },
            { "MNT", "MNT" },
            { "lkr", "Rupee Sri Lanka" },
            { "czk", "Koruna Republik Czech" },
            { "BYN", "BYN" },
            { "HUF", "HUF" },
            { "xcd", "Dolar Caribbean Timur" },
            { "BYR", "BYR" },
            { "htg", "Gourde Haiti" },
            { "BIF", "BIF" },
            { "bhd", "Dinar Bahrain" },
            { "kzt", "Tenge Kazakhstan" },
            { "szl", "Lilangeni Swazi" },
            { "yer", "Rial Yaman" },
            { "afn", "Afghani Afghanistan" },
            { "BZD", "BZD" },
            { "MOP", "MOP" },
            { "NAD", "NAD" },
            { "awg", "Florin Aruba" },
            { "npr", "Rupee Nepal" },
            { "mnt", "Tugrik Mongolia" },
            { "gbp", "Paun British" },
            { "byn", "Rubel Belarus baharu" },
            { "PEN", "PEN" },
            { "huf", "Forint Hungary" },
            { "WST", "WST" },
            { "TMT", "TMT" },
            { "byr", "Rubel Belarus (2000\u20132016)" },
            { "bif", "Franc Burundi" },
            { "GTQ", "GTQ" },
            { "CLP", "CLP" },
            { "TND", "TND" },
            { "bzd", "Dolar Belize" },
            { "mop", "Pataca Macau" },
            { "nad", "Dolar Namibia" },
            { "SLL", "SLL" },
            { "pen", "Sol Peru" },
            { "wst", "Tala Samoa" },
            { "tmt", "Manat Turkmenistan" },
            { "DOP", "DOP" },
            { "KMF", "KMF" },
            { "gtq", "Quetzal Guatemala" },
            { "clp", "Peso Chile" },
            { "tnd", "Dinar Tunisia" },
            { "GEL", "GEL" },
            { "MAD", "MAD" },
            { "sll", "Leone Sierra Leone" },
            { "TOP", "TOP" },
            { "AZN", "AZN" },
            { "PGK", "PGK" },
            { "CNH", "CNH" },
            { "UAH", "UAH" },
            { "ERN", metaValue_ERN },
            { "dop", "Peso Dominican" },
            { "kmf", "Franc Comoria" },
            { "MRO", "MRO" },
            { "gel", "Lari Georgia" },
            { "mad", "Dirham Maghribi" },
            { "azn", "Manat Azerbaijan" },
            { "top", "Pa\u2019anga Tonga" },
            { "pgk", "Kina Papua New Guinea" },
            { "BMD", "BMD" },
            { "PHP", "PHP" },
            { "cnh", "Yuan China (luar pesisir)" },
            { "uah", "Hryvnia Ukraine" },
            { "PYG", "PYG" },
            { "ern", metaValue_ERN },
            { "JMD", "JMD" },
            { "COP", "COP" },
            { "USD", "USD" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "cny", "Yuan Cina" },
            { "mru", "Ouguiya Mauritania" },
            { "ETB", "ETB" },
            { "SOS", "SOS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "LAK", "LAK" },
            { "bmd", "Dolar Bermuda" },
            { "BND", "BND" },
            { "ZMK", "ZMK" },
            { "php", "Peso Filipina" },
            { "xxx", "Mata Wang Tidak Diketahui" },
            { "LRD", "LRD" },
            { "pyg", "Guarani Paraguay" },
            { "jmd", "Dolar Jamaica" },
            { "ALL", "ALL" },
            { "ZMW", "ZMW" },
            { "cop", "Peso Colombia" },
            { "usd", "Dolar AS" },
            { "etb", "Birr Ethiopia" },
            { "GHS", "GHS" },
            { "GYD", "GYD" },
            { "KPW", "KPW" },
            { "BOB", "BOB" },
            { "MDL", "MDL" },
            { "sos", "Syiling Somali" },
            { "vef", "Bolivar Venezuela" },
            { "vuv", "Vatu Vanuatu" },
            { "lak", "Kip Laos" },
            { "AMD", "AMD" },
            { "bnd", "Dolar Brunei" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "TRY", "TRY" },
            { "LBP", "LBP" },
            { "JOD", "JOD" },
            { "lrd", "Dolar Liberia" },
            { "all", "Lek Albania" },
            { "zmw", "Kwacha Zambia" },
            { "CAD", "CAD" },
            { "MUR", "MUR" },
            { "GIP", "GIP" },
            { "RON", "RON" },
            { "ils", "Syekel Baharu Israel" },
            { "ghs", "Cedi Ghana" },
            { "gyd", "Dolar Guyana" },
            { "kpw", "Won Korea Utara" },
            { "NGN", "NGN" },
            { "bob", "Boliviano Bolivia" },
            { "mdl", "Leu Moldova" },
            { "CRC", "CRC" },
            { "PKR", "PKR" },
            { "amd", "Dram Armenia" },
            { "ANG", "ANG" },
            { "try", "Lira Turki" },
            { "lbp", "Paun Lubnan" },
            { "jod", "Dinar Jordan" },
            { "hkd", "Dolar Hong Kong" },
            { "eur", "Euro" },
            { "SRD", "SRD" },
            { "lsl", "Loti Lesotho" },
            { "LTL", "LTL" },
            { "SAR", "SAR" },
            { "TTD", "TTD" },
            { "cad", "Dolar Kanada" },
            { "MVR", "MVR" },
            { "mur", "Rupee Mauritius" },
            { "gip", "Paun Gibraltar" },
            { "ron", "Leu Romania" },
            { "AOA", "AOA" },
            { "PLN", "PLN" },
            { "SBD", "SBD" },
            { "ngn", "Naira Nigeria" },
            { "crc", "Colon Costa Rica" },
            { "pkr", "Rupee Pakistan" },
            { "ang", "Guilder Antillen Belanda" },
            { "MWK", "MWK" },
            { "srd", "Dolar Surinam" },
            { "ltl", "Litas Lithuania" },
            { "sar", "Riyal Saudi" },
            { "ttd", "Dolar Trinidad dan Tobago" },
            { "MGA", "MGA" },
            { "mvr", "Rufiyaa Maldives" },
            { "inr", "Rupee India" },
            { "BAM", "BAM" },
            { "EGP", "EGP" },
            { "SSP", "SSP" },
            { "krw", "Won Korea Selatan" },
            { "aoa", "Kwanza Angola" },
            { "jpy", "Yen Jepun" },
            { "pln", "Zloty Poland" },
            { "sbd", "Dolar Kepulauan Solomon" },
            { "NIO", "NIO" },
        };
        return data;
    }
}

==> openjdk-src-14.0.2.u12-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ms.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ms extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_ERN = "ERN";
        final Object[][] data = new Object[][] {
            { "mwk", "Kwacha Malawi" },
            { "FJD", "FJD" },
            { "MXN", "MXN" },
            { "STD", "STD" },
            { "LVL", "LVL" },
            { "SCR", "SCR" },
            { "CDF", "CDF" },
            { "BBD", "BBD" },
            { "mga", "Ariary Malagasy" },
            { "HNL", "HNL" },
            { "UGX", "UGX" },
            { "ZAR", "ZAR" },
            { "STN", "STN" },
            { "bam", "Mark Boleh Tukar Bosnia-Herzegovina" },
            { "egp", "Paun Mesir" },
            { "CUC", "CUC" },
            { "ssp", "Paun Sudan selatan" },
            { "BSD", "BSD" },
            { "nio", "Cordoba Nicaragua" },
            { "SDG", "SDG" },
            { "nzd", "Dolar New Zealand" },
            { "IQD", "IQD" },
            { "brl", "Real Brazil" },
            { "CUP", "CUP" },
            { "GMD", "GMD" },
            { "fjd", "Dolar Fiji" },
            { "RSD", "RSD" },
            { "mxn", "Peso Mexico" },
            { "std", "Dobra Sao Tome dan Principe (1977\u20132017)" },
            { "lvl", "Lats Latvia" },
            { "scr", "Rupee Seychelles" },
            { "cdf", "Franc Congo" },
            { "bbd", "Dolar Barbados" },
            { "MYR", "RM" },
            { "hnl", "Lempira Honduras" },
            { "ugx", "Syiling Uganda" },
            { "FKP", "FKP" },
            { "zar", "Rand Afrika Selatan" },
            { "stn", "Dobra Sao Tome dan Principe" },
            { "UYU", "UYU" },
            { "cuc", "Peso Boleh Tukar Cuba" },
            { "bsd", "Dolar Bahamas" },
            { "CVE", "CVE" },
            { "OMR", "OMR" },
            { "sdg", "Paun Sudan" },
            { "KES", "KES" },
            { "SEK", "SEK" },
            { "BTN", "BTN" },
            { "iqd", "Dinar Iraq" },
            { "GNF", "GNF" },
            { "cup", "Peso Cuba" },
            { "gmd", "Dalasi Gambia" },
            { "MZN", "MZN" },
            { "twd", "Dolar Taiwan Baru" },
            { "ARS", "ARS" },
            { "rsd", "Dinar Serbia" },
            { "QAR", "QAR" },
            { "myr", "Ringgit Malaysia" },
            { "IRR", "IRR" },
            { "fkp", "Paun Kepulauan Falkland" },
            { "xof", "Franc CFA BCEAO" },
            { "THB", "THB" },
            { "UZS", "UZS" },
            { "uyu", "Peso Uruguay" },
            { "BDT", "BDT" },
            { "cve", "Escudo Tanjung Verde" },
            { "omr", "Rial Oman" },
            { "LYD", "LYD" },
            { "kes", "Syiling Kenya" },
            { "sek", "Krona Sweden" },
            { "KWD", "KWD" },
            { "btn", "Ngultrum Bhutan" },
            { "RUB", "RUB" },
            { "gnf", "Franc Guinea" },
            { "ISK", "ISK" },
            { "mzn", "Metikal Mozambique" },
            { "ars", "Peso Argentina" },
            { "qar", "Rial Qatar" },
            { "MKD", "MKD" },
            { "irr", "Rial Iran" },
            { "DZD", "DZD" },
            { "thb", "Baht Thai" },
            { "uzs", "Som Uzbekistan" },
            { "xpf", "Franc CFP" },
            { "PAB", "PAB" },
            { "SGD", "SGD" },
            { "bdt", "Taka Bangladesh" },
            { "KGS", "KGS" },
            { "lyd", "Dinar Libya" },
            { "kwd", "Dinar Kuwait" },
            { "rub", "Rubel Rusia" },
            { "CHF", "CHF" },
            { "HRK", "HRK" },
            { "isk", "Krona Iceland" },
            { "DJF", "DJF" },
            { "mkd", "Denar Macedonia" },
            { "TZS", "TZS" },
            { "dzd", "Dinar Algeria" },
            { "pab", "Balboa Panama" },
            { "sgd", "Dolar Singapura" },
            { "KHR", "KHR" },
            { "IDR", "IDR" },
            { "kgs", "Som Kyrgystani" },
            { "KYD", "KYD" },
            { "BWP", "BWP" },
            { "SHP", "SHP" },
            { "TJS", "TJS" },
            { "xaf", "Franc CFA BEAC" },
            { "AED", "AED" },
            { "RWF", "RWF" },
            { "chf", "Franc Switzerland" },
            { "hrk", "Kuna Croatia" },
            { "djf", "Franc Djibouti" },
            { "DKK", "DKK" },
            { "BGN", "BGN" },
            { "MMK", "MMK" },
            { "NOK", "NOK" },
            { "SYP", "SYP" },
            { "tzs", "Syiling Tanzania" },
            { "vnd", "Dong Vietnam" },
            { "aud", "Dolar Australia" },
            { "LKR", "LKR" },
            { "khr", "Riel Kemboja" },
            { "CZK", "CZK" },
            { "idr", "Rupiah Indonesia" },
            { "kyd", "Dolar Kepulauan Cayman" },
            { "HTG", "HTG" },
            { "bwp", "Pula Botswana" },
            { "shp", "Paun Saint Helena" },
            { "tjs", "Somoni Tajikistan" },
            { "BHD", "BHD" },
            { "rwf", "Franc Rwanda" },
            { "aed", "Dirham Emiriah Arab Bersatu" },
            { "KZT", "KZT" },
            { "SZL", "SZL" },
            { "dkk", "Krone Denmark" },
            { "YER", "YER" },
            { "bgn", "Lev Bulgaria" },
            { "AFN", "AFN" },
            { "mmk", "Kyat Myanma" },
            { "nok", "Krone Norway" },
            { "syp", "Paun Syria" },
            { "AWG", "AWG" },
            { "NPR", "NPR" },
            { "MNT", "MNT" },
            { "lkr", "Rupee Sri Lanka" },
            { "czk", "Koruna Republik Czech" },
            { "BYN", "BYN" },
            { "HUF", "HUF" },
            { "xcd", "Dolar Caribbean Timur" },
            { "BYR", "BYR" },
            { "htg", "Gourde Haiti" },
            { "BIF", "BIF" },
            { "bhd", "Dinar Bahrain" },
            { "kzt", "Tenge Kazakhstan" },
            { "szl", "Lilangeni Swazi" },
            { "yer", "Rial Yaman" },
            { "afn", "Afghani Afghanistan" },
            { "BZD", "BZD" },
            { "MOP", "MOP" },
            { "NAD", "NAD" },
            { "awg", "Florin Aruba" },
            { "npr", "Rupee Nepal" },
            { "mnt", "Tugrik Mongolia" },
            { "gbp", "Paun British" },
            { "byn", "Rubel Belarus baharu" },
            { "PEN", "PEN" },
            { "huf", "Forint Hungary" },
            { "WST", "WST" },
            { "TMT", "TMT" },
            { "byr", "Rubel Belarus (2000\u20132016)" },
            { "bif", "Franc Burundi" },
            { "GTQ", "GTQ" },
            { "CLP", "CLP" },
            { "TND", "TND" },
            { "bzd", "Dolar Belize" },
            { "mop", "Pataca Macau" },
            { "nad", "Dolar Namibia" },
            { "SLL", "SLL" },
            { "pen", "Sol Peru" },
            { "wst", "Tala Samoa" },
            { "tmt", "Manat Turkmenistan" },
            { "DOP", "DOP" },
            { "KMF", "KMF" },
            { "gtq", "Quetzal Guatemala" },
            { "clp", "Peso Chile" },
            { "tnd", "Dinar Tunisia" },
            { "GEL", "GEL" },
            { "MAD", "MAD" },
            { "sll", "Leone Sierra Leone" },
            { "TOP", "TOP" },
            { "AZN", "AZN" },
            { "PGK", "PGK" },
            { "CNH", "CNH" },
            { "UAH", "UAH" },
            { "ERN", metaValue_ERN },
            { "dop", "Peso Dominican" },
            { "kmf", "Franc Comoria" },
            { "MRO", "MRO" },
            { "gel", "Lari Georgia" },
            { "MRU", "MRU" },
            { "mad", "Dirham Maghribi" },
            { "azn", "Manat Azerbaijan" },
            { "top", "Pa\u2019anga Tonga" },
            { "pgk", "Kina Papua New Guinea" },
            { "BMD", "BMD" },
            { "PHP", "PHP" },
            { "cnh", "Yuan China (luar pesisir)" },
            { "uah", "Hryvnia Ukraine" },
            { "PYG", "PYG" },
            { "ern", metaValue_ERN },
            { "JMD", "JMD" },
            { "COP", "COP" },
            { "USD", "USD" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "cny", "Yuan Cina" },
            { "mru", "Ouguiya Mauritania" },
            { "ETB", "ETB" },
            { "SOS", "SOS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "LAK", "LAK" },
            { "bmd", "Dolar Bermuda" },
            { "BND", "BND" },
            { "ZMK", "ZMK" },
            { "php", "Peso Filipina" },
            { "xxx", "Mata Wang Tidak Diketahui" },
            { "LRD", "LRD" },
            { "pyg", "Guarani Paraguay" },
            { "jmd", "Dolar Jamaica" },
            { "ALL", "ALL" },
            { "VES", "VES" },
            { "ZMW", "ZMW" },
            { "cop", "Peso Colombia" },
            { "usd", "Dolar AS" },
            { "etb", "Birr Ethiopia" },
            { "GHS", "GHS" },
            { "GYD", "GYD" },
            { "KPW", "KPW" },
            { "BOB", "BOB" },
            { "MDL", "MDL" },
            { "sos", "Syiling Somali" },
            { "vef", "Bolivar Venezuela (2008\u20132018)" },
            { "vuv", "Vatu Vanuatu" },
            { "lak", "Kip Laos" },
            { "AMD", "AMD" },
            { "bnd", "Dolar Brunei" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "TRY", "TRY" },
            { "LBP", "LBP" },
            { "JOD", "JOD" },
            { "lrd", "Dolar Liberia" },
            { "all", "Lek Albania" },
            { "ves", "Bolivar Venezuela" },
            { "zmw", "Kwacha Zambia" },
            { "CAD", "CAD" },
            { "MUR", "MUR" },
            { "GIP", "GIP" },
            { "RON", "RON" },
            { "ils", "Syekel Baharu Israel" },
            { "ghs", "Cedi Ghana" },
            { "gyd", "Dolar Guyana" },
            { "kpw", "Won Korea Utara" },
            { "NGN", "NGN" },
            { "bob", "Boliviano Bolivia" },
            { "mdl", "Leu Moldova" },
            { "CRC", "CRC" },
            { "PKR", "PKR" },
            { "amd", "Dram Armenia" },
            { "ANG", "ANG" },
            { "try", "Lira Turki" },
            { "lbp", "Paun Lubnan" },
            { "jod", "Dinar Jordan" },
            { "hkd", "Dolar Hong Kong" },
            { "eur", "Euro" },
            { "SRD", "SRD" },
            { "lsl", "Loti Lesotho" },
            { "LTL", "LTL" },
            { "SAR", "SAR" },
            { "TTD", "TTD" },
            { "cad", "Dolar Kanada" },
            { "MVR", "MVR" },
            { "mur", "Rupee Mauritius" },
            { "gip", "Paun Gibraltar" },
            { "ron", "Leu Romania" },
            { "AOA", "AOA" },
            { "PLN", "PLN" },
            { "SBD", "SBD" },
            { "ngn", "Naira Nigeria" },
            { "crc", "Colon Costa Rica" },
            { "pkr", "Rupee Pakistan" },
            { "ang", "Guilder Antillen Belanda" },
            { "MWK", "MWK" },
            { "srd", "Dolar Surinam" },
            { "ltl", "Litas Lithuania" },
            { "sar", "Riyal Saudi" },
            { "ttd", "Dolar Trinidad dan Tobago" },
            { "MGA", "MGA" },
            { "mvr", "Rufiyaa Maldives" },
            { "inr", "Rupee India" },
            { "BAM", "BAM" },
            { "EGP", "EGP" },
            { "SSP", "SSP" },
            { "krw", "Won Korea Selatan" },
            { "aoa", "Kwanza Angola" },
            { "jpy", "Yen Jepun" },
            { "pln", "Zloty Poland" },
            { "sbd", "Dolar Kepulauan Solomon" },
            { "NIO", "NIO" },
        };
        return data;
    }
}
